shithub: sox

Download patch

ref: 7c78e78c1783b72dd4a1dda12887c91b87ff4c0f
parent: 33ccbc88f1dd7052ac6ed70982bcae51e9b722f4
author: cbagwell <cbagwell>
date: Sat Sep 24 20:07:43 EDT 2005

fix typos

--- a/src/sox.c
+++ b/src/sox.c
@@ -75,7 +75,7 @@
 
 static int user_abort = 0;
 
-static int quite = 0;
+static int quiet = 0;
 static int status = 0;
 static unsigned long input_samples = 0;
 static unsigned long read_samples = 0;
@@ -386,12 +386,12 @@
 
             case 'S':
                 status = 1;
-                quite = 0;
+                quiet = 0;
                 break;
 
             case 'q':
                 status = 0;
-                quite = 1;
+                quiet = 1;
                 break;
         }
     }
@@ -507,7 +507,7 @@
             strcmp(file_desc[file_count-1]->filetype, "ossdsp") == 0 ||
             strcmp(file_desc[file_count-1]->filetype, "sunau") == 0)
         {
-            if (!quite)
+            if (!quiet)
                 status = 1;
         }
 
@@ -695,7 +695,7 @@
 
         /* If not writing and no effects are occuring then not much
          * reason to continue reading.  This allows this case.  Mainly
          * useful to print out info about input file header and quite.
          */
         if (!writing && neffects == 1)
             efftab[0].olen = 0;
@@ -695,7 +695,7 @@
         /* If not writing and no effects are occuring then not much
          * reason to continue reading.  This allows this case.  Mainly
-         * useful to print out info about input file header and quite.
+         * useful to print out info about input file header and quiet.
          */
         if (!writing && neffects == 1)